ShakeConfig class

Constructors

ShakeConfig({required double offset, List<int>? pattern, List<int>? intensities, VibrationType vibrationType = VibrationType.haptic})
const
ShakeConfig.fromPreset(ShakePreset preset)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
intensities → List<int>?
final
offset → double
final
pattern → List<int>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vibrationType → VibrationType
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited